==> dangerzone.1.0.buildkit.zip: src/dangerzone/blocks/BlockLavaFiller.java <==
package dangerzone.blocks;

import dangerzone.World;


/*
 * This code is copyright Richard H. Clark, TheyCallMeDanger, OreSpawn, 2015-2020.
 * You may use this code for reference for modding the DangerZone game program,
 * and are perfectly welcome to cut'n'paste portions for your mod as well.
 * DO NOT USE THIS CODE FOR ANY PURPOSE OTHER THAN MODDING FOR THE DANGERZONE GAME.
 * DO NOT REDISTRIBUTE THIS CODE. 
 * 
 * This copyright remains in effect until January 1st, 2021. 
 * At that time, this code becomes public domain.
 * 
 * WARNING: There are bugs. Big bugs. Little bugs. Every size in-between bugs.
 * This code is NOT suitable for use in anything other than this particular game. 
 * NO GUARANTEES of any sort are given, either express or implied, and Richard H. Clark, 
 * TheyCallMeDanger, OreSpawn are not responsible for any damages, direct, indirect, or otherwise. 
 * You should have made backups. It's your own fault for not making them.
 * 
 * NO ATTEMPT AT SECURITY IS MADE. This code is USE AT YOUR OWN RISK.
 * Regardless of what you may think, the reality is, that the moment you 
 * connected your computer to the Internet, Uncle Sam, among many others, hacked it.
 * DO NOT KEEP VALUABLE INFORMATION ON INTERNET-CONNECTED COMPUTERS.
 * Or your phone...
 * 
 */

public class BlockLavaFiller extends BlockLava {
	
	//static_partner is set in post_load_processing!
	
	public BlockLavaFiller(String n, String txt) {
		super(n, txt);
	}
	
	public void tickMe(World w, int d, int x, int y, int z){	
		super.tickMe(w, d, x, y, z);
		if(w.isServer){
			if(w.getblock(d, x, y-1, z) != 0){
				w.setblock(d, x,y,z, Blocks.stone.blockID);
			}
		}

	}
	

}

==> dangerzone.1.9.buildkit.zip: src/dangerzone/blocks/BlockLavaFiller.java <==
package dangerzone.blocks;

import dangerzone.BreakChecks;
import dangerzone.World;


/*
 * This code is copyright Richard H. Clark, TheyCallMeDanger, OreSpawn, 2015-2020.
 * You may use this code for reference for modding the DangerZone game program,
 * and are perfectly welcome to cut'n'paste portions for your mod as well.
 * DO NOT USE THIS CODE FOR ANY PURPOSE OTHER THAN MODDING FOR THE DANGERZONE GAME.
 * DO NOT REDISTRIBUTE THIS CODE. 
 * 
 * This copyright remains in effect until January 1st, 2021. 
 * At that time, this code becomes public domain.
 * 
 * WARNING: There are bugs. Big bugs. Little bugs. Every size in-between bugs.
 * This code is NOT suitable for use in anything other than this particular game. 
 * NO GUARANTEES of any sort are given, either express or implied, and Richard H. Clark, 
 * TheyCallMeDanger, OreSpawn are not responsible for any damages, direct, indirect, or otherwise. 
 * You should have made backups. It's your own fault for not making them.
 * 
 * NO ATTEMPT AT SECURITY IS MADE. This code is USE AT YOUR OWN RISK.
 * Regardless of what you may think, the reality is, that the moment you 
 * connected your computer to the Internet, Uncle Sam, among many others, hacked it.
 * DO NOT KEEP VALUABLE INFORMATION ON INTERNET-CONNECTED COMPUTERS.
 * Or your phone...
 * 
 */

public class BlockLavaFiller extends BlockLava {
	
	//static_partner is set in post_load_processing!
	
	public BlockLavaFiller(String n, String txt) {
		super(n, txt);
	}
	
	public void tickMe(World w, int d, int x, int y, int z){	
		super.tickMe(w, d, x, y, z);
		if(w.isServer){
			if(w.getblock(d, x, y-1, z) != 0){
				if(!BreakChecks.canChangeBlock(w, d, x, y, z, d, x, y, z, 0, 0))return;
				w.setblock(d, x,y,z, Blocks.stone.blockID);
			}
		}

	}
	

}
